<#assign default_header>
import { Subject } from 'rxjs';
import '@/assets/interface/viewState';
import { Environment } from '@/environments/environment';
<#if view.getPSAppViewEngines()??>
<#list view.getPSAppViewEngines() as engine>
import ${engine.getEngineType()}Engine from '@/assets/${engine.getEngineCat()?lower_case}/${srffilepath2(engine.getEngineType())}-engine';
</#list>
</#if>
<#if view.getPSControls()??>
<#list view.getPSControls() as ctrl>
<#if ctrl.getControlType() != 'TOOLBAR' && ctrl.getControlType() != 'CONTEXTMENU'>
<#if ctrl.getPSDataEntity?? && ctrl.getPSDataEntity()??>
import view_${ctrl.getName()} from '@/widget/${srffilepath2(ctrl.getPSDataEntity().getCodeName())}/${srffilepath2(ctrl.getCodeName())}-${ctrl.getControlType()?lower_case}/${srffilepath2(ctrl.getCodeName())}-${ctrl.getControlType()?lower_case}.vue';
<#else>
import view_${ctrl.getName()} from '@/widget/app/${srffilepath2(ctrl.getCodeName())}-${ctrl.getControlType()?lower_case}/${srffilepath2(ctrl.getCodeName())}-${ctrl.getControlType()?lower_case}.vue';
</#if>
</#if>
</#list>
</#if>
</#assign>
<#-- 关联组件start -->
<#assign components>
<#if view.getPSControls()??>
<#list view.getPSControls() as ctrl>
<#if ctrl.getControlType() != "TOOLBAR" && ctrl.getControlType() != 'CONTEXTMENU'>
    view_${ctrl.getName()}, 
</#if>
</#list>
</#if>
</#assign>
<#-- 关联组件end -->
<#-- 默认内容start -->
<#assign default_content>

    /**
     * 数据视图
     *
     * @type {string}
     * @memberof ${srfclassname('${view.name}')}
     */
    @Prop() public viewdata!: string;

    /**
     * 是否是嵌入分页导航视图，默认为false
     *
     * @type {string}
     * @memberof ${srfclassname('${view.name}')}
     */
    @Prop({default:false}) public isTabExp?:boolean;

    /**
     * 是否为内敛试图
     *
     * @type {boolean}
     * @memberof ${srfclassname('${view.name}')}
     */
    @Prop() public isembeddedView?: boolean;

    /**
     * 是否为模态模式
     *
     * @type {string}
     * @memberof ${srfclassname('${view.name}')}
     */
    @Prop() public isModalMode?: string;

    /**
     * 处理值变化
     *
     * @param {*} newVal
     * @param {*} oldVal
     * @memberof ${srfclassname('${view.name}')}
     */
    @Watch('viewdata')
    onViewData(newVal: any, oldVal: any) {
        const _this: any = this;
        if (!Object.is(newVal, oldVal) && _this.engine) {
            _this.engine.setViewData(newVal);
            _this.engine.load();
        }
    }

    /**
     * 容器模型
     *
     * @type {*}
     * @memberof ${srfclassname('${view.name}')}
     */
    public containerModel: any = {
        <#if view.getPSControls()??>
        <#list view.getPSControls() as ctrl>
        view_${ctrl.name}: { name: '${ctrl.name}', type: '${ctrl.getControlType()}' },
        </#list>
        </#if>
        <#if view.isPickupView()>
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
        </#if>
    };

    /**
     * 视图状态订阅对象
     *
     * @private
     * @type {Subject<{action: string, data: any}>}
     * @memberof ${srfclassname('${view.name}')}
     */
    public viewState: Subject<ViewState> = new Subject();
    <#if view.getPSAppViewEngines()??>
    <#list view.getPSAppViewEngines() as engine>
    /**
     * 视图引擎
     *
     * @private
     * @type {Engine}
     * @memberof ${srfclassname('${view.name}')}
     */
    private ${engine.getName()?lower_case}: ${engine.getEngineType()}Engine = new ${engine.getEngineType()}Engine();
    </#list>
    </#if>

    /**
     * 引擎初始化
     *
     * @private
     * @memberof ${srfclassname('${view.name}')}
     */
    private engineInit(): void {
    <#if view.getPSAppViewEngines()??>
    <#list view.getPSAppViewEngines() as engine>
        this.${engine.getName()?lower_case}.init({
            view: this,
        <#if engine.getPSAppViewEngineParams()??>
            <#list engine.getPSAppViewEngineParams() as param>
            <#if param.getParamType() == "LOGIC" && param.getPSAppViewLogic()??>
            ${param.getName()?lower_case}: (params: any) => {
                this.${param.getPSAppViewLogic().getName()}(params);
            },
            </#if>
            <#if param.getParamType() == "CTRL" && param.getPSControl()??>
            ${param.getName()?lower_case}: this.$refs.${param.getPSControl().getName()},
            </#if>
            <#if param.getParamType() == "VALUE" && param.getValue()??>
            ${param.getName()?lower_case}: '${param.getValue()?c}',
            </#if>
            </#list>
        </#if>
        });
    </#list>
    </#if>
    }

    /**
     * Vue声明周期(组件初始化完毕)
     *
     * @memberof ${srfclassname('${view.name}')}
     */
    public mounted() {
        this.handleMounted();
    }

    /**
     * 组件初始化完毕后处理逻辑
     *
     * @memberof ${srfclassname('${view.name}')}
     */
    public handleMounted(){
        <#if view.getPSAppViewEngines()??>
        this.engineInit();
        </#if>
        <#if mounted_block??>${mounted_block}</#if>
    }
    
    <#if view.getPSUIActions()??>
    <#list view.getPSUIActions() as uiAction>
    ${P.getLogicCode(uiAction, "LOGIC.vue").code}
    </#list>
    </#if>
    <#if view.getPSControls()??>
    <#list view.getPSControls() as ctrl>
    <#if ctrl.getControlType()??>
    <#if ctrl.getHookEventNames()??>
    <#list ctrl.getHookEventNames() as eventName>
    /**
     * ${ctrl.name} 部件 ${eventName?lower_case} 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof TestEntityEditView
     */
    public ${ctrl.name}_${eventName?lower_case}($event: any, $event2?: any) {
    <#if ctrl.getPSControlLogics(eventName)??>
    <#list ctrl.getPSControlLogics(eventName) as ctrlLogic>
    <#if ctrlLogic.getLogicType() == "APPVIEWENGINE" && ctrlLogic.getPSAppViewEngine()??>
        this.${ctrlLogic.getPSAppViewEngine().getName()}.onCtrlEvent('${ctrl.name}', '${eventName?lower_case}', $event);
    <#else>
        <#if ctrlLogic.getEventArg()?? && ctrlLogic.getEventArg()?length gt 0>
        if (Object.is($event.tag, '${ctrlLogic.getEventArg()}')) {
            this.${ctrlLogic.name}($event, '', $event2);
        }
        <#else>
        this.${ctrlLogic.name}($event, '', $event2);
        </#if>
    </#if>
    </#list>
    </#if>
    }

    </#list>
    </#if>
    </#if>
    </#list>
    </#if>

<#if view.getPSAppViewLogics()??>
<#list view.getPSAppViewLogics() as logic>
<#if logic.getLogicTrigger() == "CUSTOM" || logic.getLogicTrigger() == "CTRLEVENT">
${P.getLogicCode(logic, "LOGIC.vue").code}
</#if>
</#list>
</#if>
<#if view.hasPSControl('lefttoolbar')>
<#assign lefttoolbar = view.getPSControl('lefttoolbar')>
<#if lefttoolbar.getPSDEToolbarItems()??>
<#list lefttoolbar.getPSDEToolbarItems()  as toolbarItem>
<#if toolbarItem.getItemType() == "ITEMS">
<#if toolbarItem.getPSDEToolbarItems()??>

    /**
     * 打开${lefttoolbar.getName()}的ActionSheet
     *
     * @memberof ${srfclassname('${view.name}')}
     */

    public ${lefttoolbar.getName()}_openActionSheet(){
        let toolBarArray:Array<any> =[];
        <#list toolbarItem.getPSDEToolbarItems() as  deuiactionItem>
        toolBarArray.push({'name':'${deuiactionItem.getCaption()}','tag':'${deuiactionItem.getName()}'})
        </#list>
        let subject = this.$actionSheet({actions:toolBarArray}).show();
        subject.subscribe((res:any) =>{
            if(res.tag){
                this.${lefttoolbar.getName()}_click(res);
            }
        })
    }
</#if>
</#if>
</#list>
</#if>
</#if>
<#if view.hasPSControl('righttoolbar')>
<#assign righttoolbar = view.getPSControl('righttoolbar')>
<#if righttoolbar.getPSDEToolbarItems()??>
<#list righttoolbar.getPSDEToolbarItems()  as toolbarItem>
<#if toolbarItem.getItemType() == "ITEMS">
<#if toolbarItem.getPSDEToolbarItems()??>

    /**
     * 打开${righttoolbar.getName()}的ActionSheet
     *
     * @memberof ${srfclassname('${view.name}')}
     */

    public ${righttoolbar.getName()}_openActionSheet(){
        let toolBarArray:Array<any> =[];
        <#list toolbarItem.getPSDEToolbarItems() as  deuiactionItem>
        toolBarArray.push({'name':'${deuiactionItem.getCaption()}','tag':'${deuiactionItem.getName()}'})
        </#list>
        let subject = this.$actionSheet({actions:toolBarArray}).show();
        subject.subscribe((res:any) =>{
            if(res.tag){
                this.${righttoolbar.getName()}_click(res);
            }
        })
    }

</#if>
</#if>
</#list>
</#if>
</#if>
    
</#assign>